@@ -94,7 +94,7 @@ readLexisNexisHTML <- FunctionGenerator(function(elem, language, id) {
             # https://stat.ethz.ch/pipermail/r-sig-mac/2012-June/009296.html
             # Add a workaround for French
             if (Sys.info()["sysname"] == "Darwin")
-                date <- strptime(sub("[jJ]uillet", "07", strdate, "%d %m %Y"))
+                date <- strptime(sub("[jJ]uillet", "07", strdate), "%d %m %Y")
 
             if(is.na(date))
                 warning(sprintf("Could not parse document date \"%s\". You may need to change the system locale to match that of the corpus. See LC_TIME in ?Sys.setlocale.", strdate))
